package logic

import (
	"encoding/json"
	"fusenapi/constants"
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"
	"strings"

	"context"

	"fusenapi/server/webset/internal/svc"
	"fusenapi/server/webset/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
	"gorm.io/gorm"
)

type WetSetSettingLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewWetSetSettingLogic(ctx context.Context, svcCtx *svc.ServiceContext) *WetSetSettingLogic {
	return &WetSetSettingLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *WetSetSettingLogic) WetSetSetting(req *types.RequestWebSet, userinfo *auth.UserInfo) (resp *basic.Response) {
	// 返回值必须调用Set重新返回, resp可以空指针调用 resp.SetStatus(basic.CodeOK, data)
	// userinfo 传入值时, 一定不为null

	typeConf := constants.TypeWebSet(req.Type)

	//如果是这三个配置项 则读取缓存
	var result map[string]interface{}
	data, err := l.svcCtx.AllModels.FsWebSet.FindValueByKey(l.ctx, string(typeConf))
	if err != nil {
		if err == gorm.ErrRecordNotFound {
			return resp.SetStatus(basic.CodeDbRecordNotFoundErr)
		}
		return resp.SetStatus(basic.CodeDbSqlErr)
	}

	//读取配置项
	err = json.Unmarshal([]byte(*data.Value), &result)
	if err != nil {
		return resp.SetStatus(basic.CodeJsonErr)
	}
	//组装配置项的内容数据
	for k, v := range result["list"].(map[string]interface{}) {
		//按空格分隔内容
		result["list"].(map[string]interface{})[k].(map[string]interface{})["content"] = strings.Split(v.(string), "\n")
	}

	// TODO: 缓存
	if typeConf == constants.CLAUSE_CONFIG || typeConf == constants.FAQ_CONFIG || typeConf == constants.POLICY_CONFIG {
		// cache := redis.NewClient(&redis.Options{
		//     Addr:     "localhost:6379",
		//     Password: "",  // no password set
		//     DB:       0,  // use default DB
		// })
		// if cache.Exists(ctx.Query("type")).Val() > 0 {
		//     result = cache.HGetAll(ctx.Query("type")).Val()
		// } else {
		//     //读取配置项
		//     model := WebSet{Key: typeStr}
		//     db.First(&model)
		//     result = json.Unmarshal([]byte(model.Value), &result)
		//     //组装配置项的内容数据
		//     for k, v := range result["list"].(map[string]interface{}) {
		//         //按空格分隔内容
		//         result["list"].(map[string]interface{})[k].(map[string]interface{})["content"] = strings.Split(v.(string), "\n")
		//     }
		//     cache.HMSet(ctx.Query("type"), result)
		// }
	} else {

	}

	return resp.SetStatus(basic.CodeOK)
}
